/* Generated by Nim Compiler v1.4.2 */
/*   (c) 2020 Andreas Rumpf */
/* The generated code is subject to the original license. */
#define NIM_INTBITS 64

/* section: NIM_merge_HEADERS */

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix

/* section: NIM_merge_FRAME_DEFINES */
#define nimfr_(x, y)
#define nimln_(x, y)

/* section: NIM_merge_FORWARD_TYPES */
typedef struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ;
typedef struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA;
typedef struct RootObj RootObj;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tySequence__Ef05srmQTDulnBdXR4Ja6Q tySequence__Ef05srmQTDulnBdXR4Ja6Q;
typedef struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw;
typedef struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w;
typedef struct tySequence__MvZmat48bhe9b6x9aUD58D5Q tySequence__MvZmat48bhe9b6x9aUD58D5Q;
typedef struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA;
typedef struct tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA;
typedef struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ;
typedef struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q;
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA;
typedef struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw;
typedef struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ tySequence__DfgJFJEYoj4YBAHLZPl5lQ;
typedef struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA;
typedef struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg;
typedef struct tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ;
typedef struct tySequence__9brg1xNurxcus33lU4IE1Dw tySequence__9brg1xNurxcus33lU4IE1Dw;
typedef struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA tyObject_Table__fdKWDDO1P17zvuQPReVgRA;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw;
typedef struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ tySequence__bWZXqEvLFwhLvAqSRoFNgQ;
typedef struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA;
typedef struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw tyObject_Table__IioUJGdqPI6xC7S7QF8MBw;
typedef struct tySequence__Qr6E8eH7btq79cFKGaJfGLw tySequence__Qr6E8eH7btq79cFKGaJfGLw;
typedef struct tyObject_Table__G1v8c16HePOldLeucwe05Q tyObject_Table__G1v8c16HePOldLeucwe05Q;
typedef struct tySequence__fIB1rTQ55aFonoft9a9bmljQ tySequence__fIB1rTQ55aFonoft9a9bmljQ;
typedef struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA;
typedef struct tySequence__23SMqauuRsbDANhthj9bWlA tySequence__23SMqauuRsbDANhthj9bWlA;
typedef struct tyObject_Table__NttoEzoiq5CiphZe81oadg tyObject_Table__NttoEzoiq5CiphZe81oadg;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg tyObject_Table__nagDFX4QHx0s6Fvma9blmSg;
typedef struct tySequence__pHNq3oXj9av2sEUdqaqeZjw tySequence__pHNq3oXj9av2sEUdqaqeZjw;
typedef struct tySequence__PzqTLBFNawCGiqTk0UORYw tySequence__PzqTLBFNawCGiqTk0UORYw;
typedef struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw tyObject_Target__9abOl5DLX8suLujOaHSvGzw;
typedef struct tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg;
typedef struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A;
typedef struct tySequence__tNFrR3kRuS1FSwuiLGoSSA tySequence__tNFrR3kRuS1FSwuiLGoSSA;
typedef struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ tySequence__Zi9cGbCWofbtABoHJ5RbLNQ;
typedef struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw tySequence__pK3qSsBZwdXd6qyUMkd5Jw;
typedef struct tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ;
typedef struct tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig;
typedef struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA tySequence__DXS6mEo7PVUFJkirsQ9bNQA;
typedef struct tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA;
typedef struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g;
typedef struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w;
typedef struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ;
typedef struct tyObject_GcStack__7fytPA5bBsob6See21YMRA tyObject_GcStack__7fytPA5bBsob6See21YMRA;
typedef struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg;
typedef struct tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ;
typedef struct tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg;
typedef struct tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw;
typedef struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA;
typedef struct tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw;
typedef struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw;
typedef struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg;
typedef struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyTuple__ujsjpB2O9cjj3uDHsXbnSzg;
typedef struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg;
typedef struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ;
typedef struct tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg;
typedef struct tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug;
typedef struct tyTuple__zwpS6d6iewrdlBSTNFoyVA tyTuple__zwpS6d6iewrdlBSTNFoyVA;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__quA39a2QdEQU9cSEIUSibApQ tyTuple__quA39a2QdEQU9cSEIUSibApQ;
typedef struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g;
typedef struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw tyTuple__OJFzEczluV8Jmo9bRpBfkzw;
typedef struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__wcNatyuf8WOqAhGLhSvgiw tyTuple__wcNatyuf8WOqAhGLhSvgiw;
typedef struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg;
typedef struct tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g;
typedef struct tyTuple__euPCXX9bc3XzndEhYlqNS7g tyTuple__euPCXX9bc3XzndEhYlqNS7g;
typedef struct tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w;
typedef struct tyTuple__z822nu9bFF1AlQnLrHjdwpA tyTuple__z822nu9bFF1AlQnLrHjdwpA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg;
typedef struct tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA;

/* section: NIM_merge_TYPES */
typedef NU8 tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw;
typedef NU8 tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A;
typedef NU8 tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__jIBKr1ejBgsfM33Kxw4j7A kind;
tySet_tyEnum_TNimTypeFlag__v8QUszD1sWlSIWZz7mC4bQ flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA {
  RootObj Sup;
NI id;
};
typedef NU8 tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA;
typedef NU64 tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* tyArray__PsPyPA45AAjHu4uDGHNjTg[6];
typedef NU8 tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg;
typedef NU8 tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw;
typedef NU16 tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA;
struct tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA {
tyEnum_TLocKind__O7PRFZKuiBBWbku09cayVBg k;
tyEnum_TStorageLoc__JK9cKMX3XnqHaUky9b6gkGEw storage;
tySet_tyEnum_TLocFlag__o2bqJgR4ceIupnUSpxiudA flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* lode;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* r;
};
struct tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind;
tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA callConv;
tySet_tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw flags;
tySequence__Ef05srmQTDulnBdXR4Ja6Q* sons;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
tyArray__PsPyPA45AAjHu4uDGHNjTg attachedOps;
tySequence__MvZmat48bhe9b6x9aUD58D5Q* methods;
NI64 size;
NI16 align;
NI16 paddingAtEnd;
NI16 lockLevel;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typeInst;
NI uniqueId;
};
struct tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q {
NU16 line;
NI16 col;
NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg;
typedef NU8 tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw {
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tySet_tyEnum_TNodeFlag__jyh9acXHkhZANSSvPIY7ZLg flags;
tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind;
union{
struct {NI64 intVal;
} _kind_1;
struct {NF floatVal;
} _kind_2;
struct {NimStringDesc* strVal;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym;
} _kind_4;
struct {tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* ident;
} _kind_5;
struct {tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* sons;
} _kind_6;
};
NimStringDesc* comment;
};
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
NimStringDesc* Field0;
NI Field1;
NI Field2;
};
struct tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA {
NI counter;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* data;
};
typedef NI tyArray__emiAJ8okywrJw7ZHLzlXbQ[34];
struct tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg {
NI elems;
NI counter;
NI max;
tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* head;
tySequence__9brg1xNurxcus33lU4IE1Dw* data;
tyArray__emiAJ8okywrJw7ZHLzlXbQ a;
};
struct tyObject_Table__fdKWDDO1P17zvuQPReVgRA {
tySequence__fdmz6VkIf1ewwrssKYqRFg* data;
NI counter;
};
struct tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ {
tySequence__kxu4GK0onha2t9bo86mdVAg* data;
NI counter;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__OLX364rHC66WkzRbMp49aQg[64];
typedef tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* tyArray__6GDJmNRiFxkWAAdMgUie8g[70];
struct tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA {
char dummy;
};
struct tyObject_Table__IioUJGdqPI6xC7S7QF8MBw {
tySequence__Qr6E8eH7btq79cFKGaJfGLw* data;
NI counter;
};
struct tyObject_Table__G1v8c16HePOldLeucwe05Q {
tySequence__fIB1rTQ55aFonoft9a9bmljQ* data;
NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, tyProc__c6vdo1yHyj19b9bS17tijS2w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__d5yEkT9aXkAtHvVerr7IeCQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, NI32 fileIdx);
typedef N_NIMCALL_PTR(void, tyProc__sP1I7TbCn358eLy9bX4IphA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* m, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA {
tySequence__23SMqauuRsbDANhthj9bWlA* data;
NI counter;
};
struct tyObject_Table__NttoEzoiq5CiphZe81oadg {
tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data;
NI counter;
};
struct tyObject_Table__nagDFX4QHx0s6Fvma9blmSg {
tySequence__pHNq3oXj9av2sEUdqaqeZjw* data;
NI counter;
};
typedef N_NIMCALL_PTR(void, tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__3TeLOx1euAsRk3YCaQCuPg) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* formal, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* actual);
struct tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* modules;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA packageSyms;
tyObject_IntSet__PQrmFm4BXFkFSVOUl1ojSg deps;
tyObject_Table__fdKWDDO1P17zvuQPReVgRA importDeps;
NIM_BOOL suggestMode;
NIM_BOOL invalidTransitiveClosure;
tyObject_Table__e2Ciu0s1q49aVQ7ULXy7l9bQ inclToMod;
tySequence__48JTohSgTy339bRxHzUD8KA* importStack;
RootObj* backend;
tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config;
tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache;
RootObj* vm;
tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* usageSym;
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* owners;
tySequence__bWZXqEvLFwhLvAqSRoFNgQ* methods;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* systemModule;
tyArray__OLX364rHC66WkzRbMp49aQg sysTypes;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA compilerprocs;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA exposed;
tyArray__6GDJmNRiFxkWAAdMgUie8g intTypeCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opContains;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* opNot;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
tyObject_IncrementalCtx__sdH7TnbKACuAzE7DBabnCA incr;
tyObject_Table__IioUJGdqPI6xC7S7QF8MBw canonTypes;
tyObject_Table__G1v8c16HePOldLeucwe05Q symBodyHashes;
tyProc__c6vdo1yHyj19b9bS17tijS2w importModuleCallback;
tyProc__d5yEkT9aXkAtHvVerr7IeCQ includeFileCallback;
tyProc__sP1I7TbCn358eLy9bX4IphA recordStmt;
tyObject_Table__0Y2brGGKD9bV6GJLXT9aUDgA cacheSeqs;
tyObject_Table__NttoEzoiq5CiphZe81oadg cacheCounters;
tyObject_Table__nagDFX4QHx0s6Fvma9blmSg cacheTables;
tySequence__PzqTLBFNawCGiqTk0UORYw* passes;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinition;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onDefinitionResolveForward;
tyProc__R9aa9aO9cNhvWgTGK9bAAvuSRA onUsage;
tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ* globalDestructors;
tyProc__sP1I7TbCn358eLy9bX4IphA strongSemCheck;
tyProc__3TeLOx1euAsRk3YCaQCuPg compatibleProps;
};
typedef NU8 tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w;
typedef NU8 tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw;
typedef NU8 tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g;
typedef NU8 tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag;
typedef NU8 tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ;
struct tyObject_Target__9abOl5DLX8suLujOaHSvGzw {
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag targetCPU;
tyEnum_TSystemCPU__XYDt7D1G3qcClFyZy1Ky9ag hostCPU;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ targetOS;
tyEnum_TSystemOS__s7Mlr1t66SUqP6BKJMXLaQ hostOS;
NI intSize;
NI floatSize;
NI ptrSize;
NimStringDesc* tnl;
};
typedef NU32 tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg;
typedef NU64 tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA;
struct tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA {
tySequence__7lEisrXlQEzwtUKW5pzRCw* data;
NI counter;
};
struct tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q trackPos;
NIM_BOOL trackPosAttached;
tySet_tyEnum_TErrorOutput__fBf8Teueoz9aAkO5cXaxrpA errorOutputs;
tySequence__tNFrR3kRuS1FSwuiLGoSSA* msgContext;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastError;
tyObject_Table__Ab4q9c36aMR4mtkEOIBzdzA filenameToIndexTbl;
tySequence__Zi9cGbCWofbtABoHJ5RbLNQ* fileInfos;
NI32 systemFileIdx;
};
typedef NU8 tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw;
typedef NU8 tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw;
typedef NU8 tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ;
typedef NU8 tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ;
struct tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg {
tySequence__4eRCaZmrYLLw2k30GPTiMw* data;
NI counter;
};
typedef NU16 tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ;
typedef NU8 tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA;
typedef NU8 tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ;
typedef NU8 tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA;
typedef NU8 tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg[9];
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___bkMuTTb2G70XfpzAiyNrnQ* result, void* ClE_0);
void* ClE_0;
} tyProc__YD0MR9bJ2x4beJkZdnjXN9cA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringDesc* output, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* config, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* msg, tyEnum_Severity__x5BWBPGAbIH9clm5pmNp5DA severity, void* ClE_0);
void* ClE_0;
} tyProc__oL9coyIA2VDTGdUcur9aL9bew;
struct tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw {
tyEnum_TBackend__4OBsgZ9cscH2JLUE5Wcz01g backend;
tyObject_Target__9abOl5DLX8suLujOaHSvGzw target;
NI linesCompiled;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
tySet_tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw globalOptions;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* macrosToExpand;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* arcToExpand;
tyObject_MsgConfig__kV7r8HWT0SqOYW2k2ukC6A m;
NI evalTemplateCounter;
NI evalMacroCounter;
NI8 exitcode;
tyEnum_TCommands__VH3ghgQVwLSg3krOAoXigw cmd;
tyEnum_TGCMode__tkz389aDYNd8ykeZszCuBSw selectedGC;
tyEnum_ExceptionSystem__1mkAogyaDAT7g9cQjzsgKLQ exc;
NI verbosity;
NI numberOfProcessors;
NimStringDesc* evalExpr;
NF lastCmdTime;
tyEnum_SymbolFilesOption__gBES9bqm1ru9ape8SeMRAFgQ symbolFiles;
tyObject_HashSet__CD8Dpv0WGmASelVaNSo6zg cppDefines;
NimStringDesc* headerFile;
tySet_tyEnum_Feature__01UoAKYz1MxZiuG1X2VhNQ features;
tySet_tyEnum_LegacyFeature__hGCD9aOrxPvpXn4Ne6W6OVA legacyFeatures;
NimStringDesc* arguments;
tyEnum_IdeCmd__1Ced39bl5eePmZ1PKMPXigQ ideCmd;
NIM_BOOL oldNewlines;
tyEnum_TSystemCC__1eWBJUonHMOnlBwsOvpFmA cCompiler;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg modifiedyNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg cmdlineNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg foreignPackageNotes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg notes;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg warningAsErrors;
tySet_tyEnum_TMsgKind__6kx5ul0BSa9aHxHPGwkvVHg mainPackageNotes;
NI mainPackageId;
NI errorCounter;
NI hintCounter;
NI warnCounter;
NI errorMax;
NI maxLoopIterationsVM;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* configVars;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* symbols;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* packageCache;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* nimblePaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* searchPaths;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lazyPaths;
NimStringDesc* outFile;
NimStringDesc* outDir;
NimStringDesc* jsonBuildFile;
NimStringDesc* prefixDir;
NimStringDesc* libpath;
NimStringDesc* nimcacheDir;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* dllOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* moduleOverrides;
tyObject_StringTableObj__V5PVrt9bIxZEeV7lfvqqtNg* cfileSpecificOptions;
NimStringDesc* projectName;
NimStringDesc* projectPath;
NimStringDesc* projectFull;
NIM_BOOL projectIsStdin;
NIM_BOOL lastMsgWasDot;
NI32 projectMainIdx;
NI32 projectMainIdx2;
NimStringDesc* command;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* commandArgs;
NimStringDesc* commandLine;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* extraCmds;
NIM_BOOL keepComments;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitImports;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* implicitIncludes;
NimStringDesc* docSeeSrcUrl;
NimStringDesc* docRoot;
NimStringDesc* docCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cIncludes;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* cLinkedLibs;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* externalToLink;
NimStringDesc* linkOptionsCmd;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* compileOptionsCmd;
NimStringDesc* linkOptions;
NimStringDesc* compileOptions;
NimStringDesc* cCompilerPath;
tySequence__pK3qSsBZwdXd6qyUMkd5Jw* toCompile;
tyProc__YD0MR9bJ2x4beJkZdnjXN9cA suggestionResultHook;
NI suggestVersion;
NI suggestMaxResults;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q lastLineInfo;
tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
tyProc__oL9coyIA2VDTGdUcur9aL9bew structuredErrorHook;
NimStringDesc* cppCustomNamespace;
tyObject_ProfileDatacolonObjectType___rPBBfFL4X0b9cQ6rfMNPXig* vmProfileData;
};
typedef NU8 tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw;
typedef NU8 tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw;
typedef NU16 tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg;
typedef NU64 tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
struct tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw kind;
union{
struct {tySequence__Ef05srmQTDulnBdXR4Ja6Q* typeInstCache;
} _kind_1;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* procInstCache;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* gcUnsafetyReason;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* transformedBody;
} _kind_2;
struct {tySequence__DXS6mEo7PVUFJkirsQ9bNQA* usedGenerics;
tyObject_TStrTable__f07aOS3dr28kGa5wcE29aFA tab;
} _kind_3;
struct {tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* guard;
NI bitsize;
NI alignment;
} _kind_4;
};
tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg magic;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name;
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner;
tySet_tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw flags;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ast;
tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options;
NI position;
NI offset;
tyObject_TLoc__EtHNvCB0bgfu9bFjzx9cb6aA loc;
tyObject_TLib__NBMxlJ6g3utqUlplqTTHkA* annex;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* constraint;
};
struct tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA {
  tyObject_TIdObj__iIXPrEsiKHiioLj0HSkQhA Sup;
NimStringDesc* s;
tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* next;
NI h;
};
typedef NU8 tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw;
struct tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__7fytPA5bBsob6See21YMRA {
void* bottom;
};
struct tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w {
NI len;
NI cap;
tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g** d;
};
typedef tyObject_SmallChunk__tXn60W2f8h3jgAYdEmy5NQ* tyArray__SPr7N6UKfuF549bNPiUvSRw[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* tyArray__N1u1nqOgmuJN9cSZrnMHgOQ[32];
typedef tyArray__N1u1nqOgmuJN9cSZrnMHgOQ tyArray__B6durA4ZCi1xjJvRtyYxMg[24];
typedef tyObject_Trunk__W0r8S0Y3UGke6T9bIUWnnuw* tyArray__lh2A89ahMmYg9bCmpVaplLbA[256];
struct tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA {
tyArray__lh2A89ahMmYg9bCmpVaplLbA data;
};
typedef tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* tyArray__0aOLqZchNi8nWtMTi8ND8w[2];
struct tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw {
tyArray__0aOLqZchNi8nWtMTi8ND8w link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__ujsjpB2O9cjj3uDHsXbnSzg {
tyObject_BigChunk__Rv9c70Uhp2TytkX7eH78qEg* Field0;
NI Field1;
};
typedef tyTuple__ujsjpB2O9cjj3uDHsXbnSzg tyArray__LzOv2eCDGiceMKQstCLmhw[30];
struct tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg {
NI len;
tyArray__LzOv2eCDGiceMKQstCLmhw chunks;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg* next;
};
struct tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg {
NI minLargeObj;
NI maxLargeObj;
tyArray__SPr7N6UKfuF549bNPiUvSRw freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__B6durA4ZCi1xjJvRtyYxMg matrix;
tyObject_LLChunk__XsENErzHIZV9bhvyJx56wGw* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__EZObFrE3NC9bIb3YMkY9crZA chunkStarts;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* root;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* deleted;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* last;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__IaqjtwKhxLEpvDS9bct9blEw bottomData;
tyObject_HeapLinks__PDV1HBZ8CQSQJC9aOBFNRSg heapLinks;
};
struct tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ {
NI counter;
NI max;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg* head;
tyObject_PageDesc__fublkgIY4LG3mT51LU2WHg** data;
};
struct tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ {
tyObject_GcStack__7fytPA5bBsob6See21YMRA stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w zct;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w decStack;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w tempStack;
NI recGcLock;
tyObject_MemRegion__x81NhDv59b8ercDZ9bi85jyg region;
tyObject_GcStat__0RwLoVBHZPfUAcLczmfQAg stat;
tyObject_CellSet__jG87P0AI9aZtss9ccTYBIISQ marked;
tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w additionalRoots;
NI gcThreadId;
};
typedef NU8 tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw;
typedef NU64 tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag;
typedef NU8 tyEnum_TFlowVarKind__lRz5UxeDppZADNanmNd5Yw;
typedef NU8 tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw;
struct tyTuple__zwpS6d6iewrdlBSTNFoyVA {
NI Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
NI Field0;
NI32 Field1;
tySequence__48JTohSgTy339bRxHzUD8KA* Field2;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
NI Field0;
NI32 Field1;
NI32 Field2;
};
struct tyTuple__quA39a2QdEQU9cSEIUSibApQ {
tySequence__DfgJFJEYoj4YBAHLZPl5lQ* Field0;
tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* Field1;
};
typedef NU8 tyArray__qtqsWM5aXmcpMIVmvq3kAA[16];
struct tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g {
NI Field0;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field1;
tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* Field2;
};
struct tyTuple__OJFzEczluV8Jmo9bRpBfkzw {
NI Field0;
NI Field1;
tyArray__qtqsWM5aXmcpMIVmvq3kAA Field2;
};
struct tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw {
NI Field0;
NimStringDesc* Field1;
tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* Field2;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
NI Field0;
NimStringDesc* Field1;
NI64 Field2;
};
struct tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg {
tyObject_NodecolonObjectType___dNELmBSmY7nthjhZupWO6g* root;
NI entries;
};
struct tyTuple__wcNatyuf8WOqAhGLhSvgiw {
NI Field0;
NimStringDesc* Field1;
tyObject_BTree__VZdzO0Tlflp7WMN4gS8oPg Field2;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w*, tyProc__8ooe5vdoqmvpHnfXV29bP3w) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* module);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__A7Sdoem70tRxSEmKrf9cmyg) (tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* topLevelStmt);
typedef N_NIMCALL_PTR(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, tyProc__EAEKmBUgKFg29agoUGtzDEQ) (tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* graph, tyObject_TPassContext__Hb6rFM0ecvtlLf2kv9aU75w* p, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
struct tyTuple__euPCXX9bc3XzndEhYlqNS7g {
tyProc__8ooe5vdoqmvpHnfXV29bP3w Field0;
tyProc__A7Sdoem70tRxSEmKrf9cmyg Field1;
tyProc__EAEKmBUgKFg29agoUGtzDEQ Field2;
NIM_BOOL Field3;
};
struct tyTuple__z822nu9bFF1AlQnLrHjdwpA {
tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q Field0;
NimStringDesc* Field1;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
NI Field0;
NimStringDesc* Field1;
NI32 Field2;
};
struct tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw {
NimStringDesc* fullPath;
NimStringDesc* projPath;
NimStringDesc* shortName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedName;
tyObject_RopeObj__OFzf0kSiPTcNreUIeJgWVA* quotedFullName;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* lines;
NimStringDesc* dirtyFile;
NimStringDesc* hash;
NIM_BOOL dirty;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
NI Field0;
NimStringDesc* Field1;
};
typedef NU8 tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA;
struct tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg {
NimStringDesc* nimname;
NimStringDesc* cname;
NimStringDesc* obj;
tySet_tyEnum_CfileFlag__Vl9c9ayddDuXiWtnWTsEYGsA flags;
NimStringDesc* customArgs;
};

/* section: NIM_merge_SEQ_TYPES */
struct tySequence__Ef05srmQTDulnBdXR4Ja6Q {
  TGenericSeq Sup;
  tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* data[SEQ_DECL_SIZE];
};
struct tySequence__MvZmat48bhe9b6x9aUD58D5Q {
  TGenericSeq Sup;
  tyTuple__zwpS6d6iewrdlBSTNFoyVA data[SEQ_DECL_SIZE];
};
struct tySequence__ehmV9bTklH2Gt9cXHV9c0HLeQ {
  TGenericSeq Sup;
  tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* data[SEQ_DECL_SIZE];
};
struct tySequence__DfgJFJEYoj4YBAHLZPl5lQ {
  TGenericSeq Sup;
  tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* data[SEQ_DECL_SIZE];
};
struct tySequence__9brg1xNurxcus33lU4IE1Dw {
  TGenericSeq Sup;
  tyObject_Trunk__ul49aWfv9aes8cutmeltT3gQ* data[SEQ_DECL_SIZE];
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  TGenericSeq Sup;
  NI32 data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  TGenericSeq Sup;
  tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  TGenericSeq Sup;
  tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__bWZXqEvLFwhLvAqSRoFNgQ {
  TGenericSeq Sup;
  tyTuple__quA39a2QdEQU9cSEIUSibApQ data[SEQ_DECL_SIZE];
};
struct tySequence__Qr6E8eH7btq79cFKGaJfGLw {
  TGenericSeq Sup;
  tyTuple__EkGTYRWQ6y9cppXTlT8Xm5g data[SEQ_DECL_SIZE];
};
struct tySequence__fIB1rTQ55aFonoft9a9bmljQ {
  TGenericSeq Sup;
  tyTuple__OJFzEczluV8Jmo9bRpBfkzw data[SEQ_DECL_SIZE];
};
struct tySequence__23SMqauuRsbDANhthj9bWlA {
  TGenericSeq Sup;
  tyTuple__2SGm9aGCXuo7XSQ9bqD29axXw data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  TGenericSeq Sup;
  tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__pHNq3oXj9av2sEUdqaqeZjw {
  TGenericSeq Sup;
  tyTuple__wcNatyuf8WOqAhGLhSvgiw data[SEQ_DECL_SIZE];
};
struct tySequence__PzqTLBFNawCGiqTk0UORYw {
  TGenericSeq Sup;
  tyTuple__euPCXX9bc3XzndEhYlqNS7g data[SEQ_DECL_SIZE];
};
struct tySequence__tNFrR3kRuS1FSwuiLGoSSA {
  TGenericSeq Sup;
  tyTuple__z822nu9bFF1AlQnLrHjdwpA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  TGenericSeq Sup;
  tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__Zi9cGbCWofbtABoHJ5RbLNQ {
  TGenericSeq Sup;
  tyObject_TFileInfo__GE3hAakXKOEpch4ap3zXAw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  TGenericSeq Sup;
  tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__pK3qSsBZwdXd6qyUMkd5Jw {
  TGenericSeq Sup;
  tyObject_Cfile__i9cKq1ZGd1wgagjUEHLVFtg data[SEQ_DECL_SIZE];
};
struct tySequence__DXS6mEo7PVUFJkirsQ9bNQA {
  TGenericSeq Sup;
  tyObject_TInstantiation__5LqgVn6Tq9ainQRK7TQAQxA* data[SEQ_DECL_SIZE];
};

/* section: NIM_merge_PROC_HEADERS */
static N_INLINE(NIM_BOOL, isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsGarbageCollectedRef__IVXYI9cxSeivThgKCncHRnA_3)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw, spawnResult__115WOpmSjJFT089amuDIXdA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, NIM_BOOL inParallel);
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(void, addInt__mftMOxbyu0h4yByfs3sqjA)(NimStringDesc** result, NI64 x);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* errMsg, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__vokyXY9cZDshCSxFKChhG9bg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__Q6JNH4uRwLyZrj0dJakHew)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w msg, NimStringDesc* arg, tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw eh, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2, NIM_BOOL isRaw);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___qX5C9b0n9bOP7jk69amC8dA7A)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, rawNewString)(NI space);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, newSym__IXbidcxhXTQGZY9abN63Cxg)(tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw symKind, tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* name, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tySet_tyEnum_TOption__WspMeQySXNP2XoTWR5MTgg options);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*, getIdent__9coBOmdXN09be4rJvXK6fQGQ)(tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* ic, NimStringDesc* identifier);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y);
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr);
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y);
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__Y66tOYFjgwJ0k4aLz4bc0Q)(tyObject_CellSeq__Axo1XVm9aaQueTOldv8le5w* s, tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, createObj__vpIcmDdKH7ed0dcs37b1GQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NIM_BOOL final);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, createCastExpr__0ABsbrKg8HOlgwf7OVsO6A)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* argsParam, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* objType);
N_LIB_PRIVATE N_NIMCALL(void, add__P8dDSotTW25BkfbyspojGg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* son);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newSymNode__I2DV2TmmOysY1ZEGW19b9bRg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* sym);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, newType__SNqpa06pdVCLFFBR28119aQ)(tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kind, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner);
N_LIB_PRIVATE N_NIMCALL(void, rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* father, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* son, NIM_BOOL propagateHasAsgn);
N_LIB_PRIVATE N_NIMCALL(void, addVar__qOCBdprWtK4hxer73SEdQA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* father, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, tySet_tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag kinds);
N_LIB_PRIVATE N_NIMCALL(void, addField__hrnJBvN8tSy4gj6R5QDcYw)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* obj, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* s, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newFastAsgnStmt__yLsKlJlR2cWU9b7Mx2ZywyQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newDotExpr__x72gZ9bZdJ0oRpEQKtQFrrg)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* obj, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, indirectAccess__fh4Yh9bIIARGtqRFUnv8SDA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* b, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, setupArgsForConcurrency__uvJ57za4ek56COpyhrRjcw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* objType, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* scratchObj, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* castExpr, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varSection, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varInit, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, addLocalVar__V3n0eo3maUY9aznyMJYO7VQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varSection, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varInit, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v, NIM_BOOL useShallowCopy);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NI children);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newFastMoveStmt__tv3l2P9bd1TqAvC9a8QMPzqQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, typeNeedsNoDeepCopy__gutM7rfeVKrBOFkTc2e9bFg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*, lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getSysMagic__F0sH3uZM4wsRv4Pi1Pzwlg)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NimStringDesc* name, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m);
N_LIB_PRIVATE N_NIMCALL(void, setupArgsForParallelism__uvJ57za4ek56COpyhrRjcw_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* objType, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* scratchObj, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* castExpr, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varSection, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varInit, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, createMagic__MzNJxZ0htpjW89c9b2wBN5rQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NimStringDesc* name, tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg m);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg, getMagic__4W1ZJaFiusqlhViRx9cbM9bw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* op);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, genAddrOf__llCeDV6q0X9bzDY9agj6OpdQ)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag typeKind);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, genHigh__MV2CjVA8K8K4UngVlqWOhQ_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newIntLit__TuFlkTIoJNHT6fCcycYtSw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, NI64 value);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, genDeref__jR9bSEA7HO9bL5cUIVgwq7pw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw k);
N_LIB_PRIVATE N_NIMCALL(NI64, computeSize__vCG1GF2Iu043oALVyuJfOw_3)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* conf, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getRoot__QppXrRxPfamDSGF2rYPMlw)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NimStringDesc* name);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, callProc__7hKLeSMJvLb9cxdy5sc2cbg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, callCodegenProc__6cD4vACMYqPEkcqC9cypTrw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, NimStringDesc* name, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg1, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg2, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* arg3, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* optionalArgs);
N_LIB_PRIVATE N_NIMCALL(void, createTypeBoundOps__HRpOwQj0TjFM8eZsKc7jlw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* orig, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info);
N_LIB_PRIVATE N_NIMCALL(void, createWrapperProc__0GDSFHu1rWYoG5bDx2g4NQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* f, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* threadParam, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* argsParam, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varSection, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varInit, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* barrier, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fv, tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw spawnKind, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newAsgnStmt__yLsKlJlR2cWU9b7Mx2ZywyQ_2)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* le, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* ri);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, indirectAccess__p9aRoyveyldMagH4qkQksIA)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a, NimStringDesc* b, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_IdentCachecolonObjectType___TzLHS09bRH9a0TYLs39cqcNaw* cache);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TFlowVarKind__lRz5UxeDppZADNanmNd5Yw, flowVarKind__KlDLjCOjghC9c9a79chxEXrnA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, typeToString__QlvraUan7WbHowhAbvDvdA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw prefer);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, newProcNode__g5PEkYP0A0RT03uHbJ6wKQ)(tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw kind, tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q info, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* params, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* name, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pattern, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* genericParams, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* pragmas, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* exceptions);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nimIntToStr)(NI x);

/* section: NIM_merge_DATA */
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_2, "(", 1);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_3, ", ", 2);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_4, ")", 1);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_6, "/home/runner/work/nightlies/nightlies/nim/compiler/spawn.nim", 60);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__OiEZ9cmMV1ztTwyI7NGH1RQ_5 = {((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_6),
((NI) 314),
((NI) 19)}
;
extern NIM_CONST tyObject_TLineInfo__WGx4rAexNXnczy1Avn646Q unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__OiEZ9cmMV1ztTwyI7NGH1RQ_7 = {((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_6),
((NI) 317),
((NI) 19)}
;
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_8, "\'spawn\' must not be discarded", 29);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__OiEZ9cmMV1ztTwyI7NGH1RQ_9 = {((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_6),
((NI) 320),
((NI) 30)}
;
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_10, "\'spawn\' takes a call expression; got ", 37);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__OiEZ9cmMV1ztTwyI7NGH1RQ_11 = {((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_6),
((NI) 324),
((NI) 14)}
;
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_12, "\'spawn\' takes a GC safe call expression", 39);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__OiEZ9cmMV1ztTwyI7NGH1RQ_13 = {((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_6),
((NI) 328),
((NI) 16)}
;
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_14, ":tmp", 4);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_15, "Wrapper", 7);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_16, "thread", 6);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_17, "args", 4);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_18, "scratch", 7);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_19, "closure in spawn environment is not allowed", 43);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__OiEZ9cmMV1ztTwyI7NGH1RQ_20 = {((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_6),
((NI) 360),
((NI) 14)}
;
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_21, "fn", 2);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_22, "iterator in spawn environment is not allowed", 44);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__OiEZ9cmMV1ztTwyI7NGH1RQ_23 = {((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_6),
((NI) 371),
((NI) 14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__OiEZ9cmMV1ztTwyI7NGH1RQ_24 = {((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_6),
((NI) 373),
((NI) 14)}
;
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_25, "\'spawn\'ed function cannot have a \'var\' parameter", 48);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__OiEZ9cmMV1ztTwyI7NGH1RQ_26 = {((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_6),
((NI) 206),
((NI) 18)}
;
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_27, "deepCopy", 8);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_28, "slice", 5);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_29, "Barrier", 7);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_30, "barrier", 7);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_31, "fv", 2);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_32, "nimFlowVarCreateSemaphore", 25);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_33, "barrierEnter", 12);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__OiEZ9cmMV1ztTwyI7NGH1RQ_34 = {((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_6),
((NI) 128),
((NI) 19)}
;
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_35, "owner", 5);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_36, "nimArgsPassingDone", 18);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_37, "cannot create a flowVar of type: ", 33);
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__OiEZ9cmMV1ztTwyI7NGH1RQ_38 = {((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_6),
((NI) 145),
((NI) 16)}
;
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_39, "data", 4);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_40, "blob", 4);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_41, "GCref", 5);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_42, "nimFlowVarSignal", 16);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_43, "barrierLeave", 12);
STRING_LITERAL(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_44, "nimSpawn", 8);

/* section: NIM_merge_VARS */
extern tyObject_GcHeap__1TRH1TZMaVZTnLNcIHuNFQ gch__IcYaEuuWivYAS86vFMTS3Q;

/* section: NIM_merge_PROCS */
static N_INLINE(NIM_BOOL, isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = (t == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL));
	if (T1_) goto LA2_;
	T1_ = ((IL64(-9223372036854775680) &((NU64)1<<((NU)((*t).kind)&63U)))!=0);
	LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw, spawnResult__115WOpmSjJFT089amuDIXdA)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t, NIM_BOOL inParallel) {
	tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw result;
	result = (tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmptyType__nPImuPGZIdcrAfCNyf4oxA_2ast(t);
		if (!T3_) goto LA4_;
		result = ((tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw) 0);
	}
	goto LA1_;
	LA4_: ;
	{
		NIM_BOOL T7_;
		NIM_BOOL T9_;
		T7_ = (NIM_BOOL)0;
		T7_ = inParallel;
		if (!(T7_)) goto LA8_;
		T9_ = (NIM_BOOL)0;
		T9_ = containsGarbageCollectedRef__IVXYI9cxSeivThgKCncHRnA_3(t);
		T7_ = !(T9_);
		LA8_: ;
		if (!T7_) goto LA10_;
		result = ((tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw) 2);
	}
	goto LA1_;
	LA10_: ;
	{
		result = ((tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw) 1);
	}
	LA1_: ;
	return result;
}
static N_INLINE(NI, len__P89cqdlERShb9alU3iC0yj8wast)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n) {
	NI result;
	NI T1_;
	result = (NI)0;
	T1_ = ((*n)._kind_6.sons ? (*n)._kind_6.sons->Sup.len : 0);
	result = T1_;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__i80o3k0SgEI5gTRCzYdyWAsystem)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__i80o3k0SgEI5gTRCzYdyWAsystem(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
static N_INLINE(NimStringDesc*, toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info) {
	NimStringDesc* result;
	result = (NimStringDesc*)0;
	result = resizeString(result, (info.Field0 ? info.Field0->Sup.len : 0) + 0);
appendString(result, info.Field0);
	{
		if (!(((NI) 0) < info.Field1)) goto LA3_;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_2));
		addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) (info.Field1)));
		{
			if (!(((NI) 0) < (NI)(info.Field2 + ((NI) 1)))) goto LA7_;
			result = resizeString(result, 2);
appendString(result, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_3));
			addInt__mftMOxbyu0h4yByfs3sqjA((&result), ((NI64) ((NI)(info.Field2 + ((NI) 1)))));
		}
		LA7_: ;
		result = resizeString(result, 1);
appendString(result, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_4));
	}
	LA3_: ;
	return result;
}
static N_INLINE(NI, pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) + (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__AT1eRuflKWyTTBdLjEDZbg_3system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = pluspercent___dgYAo7RfdUVVpvkfKDym8wsystem((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU64)(((NU) (x))) - (NU64)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*, usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem)(void* usr) {
	tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* result;
	NI T1_;
	result = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system(((NI) (ptrdiff_t) (usr)), ((NI) 16));
	result = ((tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU64)(((NU) (x))) < (NU64)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	addZCT__Y66tOYFjgwJ0k4aLz4bc0Q((&gch__IcYaEuuWivYAS86vFMTS3Q.zct), c);
}
static N_INLINE(void, decRef__AT1eRuflKWyTTBdLjEDZbgsystem)(tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* c) {
	(*c).refcount = minuspercent___dgYAo7RfdUVVpvkfKDym8w_2system((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___hPljn3JCDQ00ua1R07X9bxQsystem((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__AT1eRuflKWyTTBdLjEDZbg_2system(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T5_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem(src);
		incRef__AT1eRuflKWyTTBdLjEDZbg_3system(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__1zcF9cV8XIAtbN8h5HRUB8g*)0;
		T10_ = usrToCell__QFQqcLB3lgOdwipkv9a60xwsystem((*dest));
		decRef__AT1eRuflKWyTTBdLjEDZbgsystem(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, createCastExpr__0ABsbrKg8HOlgwf7OVsO6A)(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* argsParam, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* objType) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T2_;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 61), (*argsParam).info);
	T1_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*argsParam).info);
	add__P8dDSotTW25BkfbyspojGg(result, T1_);
	T2_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T2_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(argsParam);
	add__P8dDSotTW25BkfbyspojGg(result, T2_);
	asgnRef((void**) (&(*result).typ), newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21), (*objType).owner));
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg((*result).typ, objType, NIM_TRUE);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, typeNeedsNoDeepCopy__gutM7rfeVKrBOFkTc2e9bFg)(tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	NIM_BOOL result;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t_2;
	NIM_BOOL T9_;
{	result = (NIM_BOOL)0;
	t_2 = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36134350135273744));
	{
		if (!((*t_2).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 28))) goto LA3_;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	LA3_: ;
	{
		if (!((IL64(140737513521152) &((NU64)1<<((NU)((*t_2).kind)&63U)))!=0)) goto LA7_;
		t_2 = lastSon__Bdq9aiV9buvJtPvmOc0OR5JQ(t_2);
	}
	LA7_: ;
	T9_ = (NIM_BOOL)0;
	T9_ = containsGarbageCollectedRef__IVXYI9cxSeivThgKCncHRnA_3(t_2);
	result = !(T9_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*, addLocalVar__V3n0eo3maUY9aznyMJYO7VQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varSection, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varInit, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* v, NIM_BOOL useShallowCopy) {
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T1_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* vpart;
	result = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	T1_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T1_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*g).cache, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_14));
	result = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 5), T1_, owner, (*varSection).info, (*owner).options);
	asgnRef((void**) (&(*result).typ), typ);
	(*result).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 2)) & 63);
	vpart = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 35), (*varSection).info, ((NI) 3));
	asgnRef((void**) (&(*vpart)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(result));
	asgnRef((void**) (&(*vpart)._kind_6.sons->data[((NI) 1)]), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*varSection).info));
	{
		if (!(varInit == 0)) goto LA4_;
		asgnRef((void**) (&(*vpart)._kind_6.sons->data[((NI) 2)]), v);
	}
	goto LA2_;
	LA4_: ;
	{
		asgnRef((void**) (&(*vpart)._kind_6.sons->data[((NI) 2)]), (*vpart)._kind_6.sons->data[((NI) 1)]);
	}
	LA2_: ;
	add__P8dDSotTW25BkfbyspojGg(varSection, vpart);
	{
		if (!!((varInit == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA9_;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T15_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T16_;
			if (!((48 &((NU16)1<<((NU)((*(*g).config).selectedGC)&15U)))!=0)) goto LA13_;
			T15_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T15_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(result);
			T16_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T16_ = newFastMoveStmt__tv3l2P9bd1TqAvC9a8QMPzqQ(g, T15_, v);
			add__P8dDSotTW25BkfbyspojGg(varInit, T16_);
		}
		goto LA11_;
		LA13_: ;
		{
			{
				NIM_BOOL T20_;
				NIM_BOOL T21_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T26_;
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T27_;
				T20_ = (NIM_BOOL)0;
				T21_ = (NIM_BOOL)0;
				T21_ = useShallowCopy;
				if (!(T21_)) goto LA22_;
				T21_ = typeNeedsNoDeepCopy__gutM7rfeVKrBOFkTc2e9bFg(typ);
				LA22_: ;
				T20_ = T21_;
				if (T20_) goto LA23_;
				T20_ = (((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 41))&63U)))!=0);
				LA23_: ;
				if (!T20_) goto LA24_;
				T26_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T26_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(result);
				T27_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
				T27_ = newFastMoveStmt__tv3l2P9bd1TqAvC9a8QMPzqQ(g, T26_, v);
				add__P8dDSotTW25BkfbyspojGg(varInit, T27_);
			}
			goto LA18_;
			LA24_: ;
			{
				tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* deepCopyCall;
				tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T29_;
				deepCopyCall = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*varInit).info, ((NI) 3));
				T29_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
				T29_ = getSysMagic__F0sH3uZM4wsRv4Pi1Pzwlg(g, (*varSection).info, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_27), ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 195));
				asgnRef((void**) (&(*deepCopyCall)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T29_));
				asgnRef((void**) (&(*deepCopyCall)._kind_6.sons->data[((NI) 1)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(result));
				asgnRef((void**) (&(*deepCopyCall)._kind_6.sons->data[((NI) 2)]), v);
				add__P8dDSotTW25BkfbyspojGg(varInit, deepCopyCall);
			}
			LA18_: ;
		}
		LA11_: ;
	}
	LA9_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setupArgsForConcurrency__uvJ57za4ek56COpyhrRjcw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* objType, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* scratchObj, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* castExpr, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varSection, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varInit, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* formals;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* tmpName;
	formals = (*(*(*n)._kind_6.sons->data[((NI) 0)]).typ).n;
	tmpName = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*g).cache, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_14));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* argType;
					tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* fieldname;
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T24_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T25_;
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* temp;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T26_;
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T27_;
					argType = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[i]).typ, IL64(36134350135273744));
					{
						NI T7_;
						T7_ = (NI)0;
						T7_ = len__P89cqdlERShb9alU3iC0yj8wast(formals);
						if (!(i < T7_)) goto LA8_;
						{
							if (!((IL64(140737496743936) &((NU64)1<<((NU)((*(*(*formals)._kind_6.sons->data[i]).typ).kind)&63U)))!=0)) goto LA12_;
							liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*(*n)._kind_6.sons->data[i]).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_25), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__OiEZ9cmMV1ztTwyI7NGH1RQ_26, NIM_FALSE);
						}
						LA12_: ;
						{
							if (!((IL64(1152921504606847232) &((NU64)1<<((NU)((*(*(*formals)._kind_6.sons->data[i]).typ).kind)&63U)))!=0)) goto LA16_;
							goto LA4;
						}
						LA16_: ;
					}
					LA8_: ;
					{
						NI T20_;
						T20_ = (NI)0;
						T20_ = len__P89cqdlERShb9alU3iC0yj8wast(formals);
						if (!(i < T20_)) goto LA21_;
						fieldname = (*(*(*formals)._kind_6.sons->data[i])._kind_4.sym).name;
					}
					goto LA18_;
					LA21_: ;
					{
						fieldname = tmpName;
					}
					LA18_: ;
					field = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19), fieldname, (*objType).owner, (*n).info, (*(*g).config).options);
					asgnRef((void**) (&(*field).typ), argType);
					addField__hrnJBvN8tSy4gj6R5QDcYw(objType, field, (*g).cache);
					T24_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T24_ = newDotExpr__x72gZ9bZdJ0oRpEQKtQFrrg(scratchObj, field);
					T25_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T25_ = newFastAsgnStmt__yLsKlJlR2cWU9b7Mx2ZywyQ(T24_, (*n)._kind_6.sons->data[i]);
					add__P8dDSotTW25BkfbyspojGg(result, T25_);
					T26_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T26_ = indirectAccess__fh4Yh9bIIARGtqRFUnv8SDA(castExpr, field, (*n).info);
					temp = addLocalVar__V3n0eo3maUY9aznyMJYO7VQ(g, varSection, varInit, owner, argType, T26_, NIM_FALSE);
					T27_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
					T27_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(temp);
					add__P8dDSotTW25BkfbyspojGg(call, T27_);
				} LA4: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, setupArgsForParallelism__uvJ57za4ek56COpyhrRjcw_2)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* objType, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* scratchObj, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* castExpr, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varSection, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varInit, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* formals;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* tmpName;
	formals = (*(*(*n)._kind_6.sons->data[((NI) 0)]).typ).n;
	tmpName = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*g).cache, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_14));
	{
		NI i;
		NI colontmp_;
		NI i_2;
		i = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__P89cqdlERShb9alU3iC0yj8wast(n);
		i_2 = ((NI) 1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i = i_2;
				{
					tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n_2;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* argType;
					tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T12_;
					tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* fieldname;
					tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
					n_2 = (*n)._kind_6.sons->data[i];
					{
						NIM_BOOL T7_;
						NI T8_;
						T7_ = (NIM_BOOL)0;
						T8_ = (NI)0;
						T8_ = len__P89cqdlERShb9alU3iC0yj8wast(formals);
						T7_ = (i < T8_);
						if (!(T7_)) goto LA9_;
						T7_ = ((IL64(1152921504606847232) &((NU64)1<<((NU)((*(*(*formals)._kind_6.sons->data[i]).typ).kind)&63U)))!=0);
						LA9_: ;
						if (!T7_) goto LA10_;
						goto LA4;
					}
					LA10_: ;
					T12_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
					{
						NI T15_;
						T15_ = (NI)0;
						T15_ = len__P89cqdlERShb9alU3iC0yj8wast(formals);
						if (!(i < T15_)) goto LA16_;
						T12_ = (*(*formals)._kind_6.sons->data[i]).typ;
					}
					goto LA13_;
					LA16_: ;
					{
						T12_ = (*n_2).typ;
					}
					LA13_: ;
					argType = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(T12_, IL64(36134350135273744));
					{
						NI T21_;
						T21_ = (NI)0;
						T21_ = len__P89cqdlERShb9alU3iC0yj8wast(formals);
						if (!(i < T21_)) goto LA22_;
						fieldname = (*(*(*formals)._kind_6.sons->data[i])._kind_4.sym).name;
					}
					goto LA19_;
					LA22_: ;
					{
						fieldname = tmpName;
					}
					LA19_: ;
					field = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19), fieldname, (*objType).owner, (*n_2).info, (*(*g).config).options);
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* slice;
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T29_;
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fieldB;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T48_;
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* threadLocal_2;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T49_;
						if (!((IL64(281475110928384) &((NU64)1<<((NU)((*argType).kind)&63U)))!=0)) goto LA27_;
						slice = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n_2).info, ((NI) 4));
						asgnRef((void**) (&(*slice).typ), (*n_2).typ);
						T29_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
						T29_ = createMagic__MzNJxZ0htpjW89c9b2wBN5rQ(g, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_28), ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 126));
						asgnRef((void**) (&(*slice)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T29_));
						asgnRef((void**) (&(*(*slice)._kind_6.sons->data[((NI) 0)]).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg(g, (*n_2).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31)));
						fieldB = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19), tmpName, (*objType).owner, (*n_2).info, (*(*g).config).options);
						asgnRef((void**) (&(*fieldB).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg(g, (*n_2).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31)));
						addField__hrnJBvN8tSy4gj6R5QDcYw(objType, fieldB, (*g).cache);
						{
							tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg T32_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T35_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T36_;
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* fieldA;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T37_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T38_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T39_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T40_;
							tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* threadLocal_1;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T41_;
							T32_ = (tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg)0;
							T32_ = getMagic__4W1ZJaFiusqlhViRx9cbM9bw(n_2);
							if (!(T32_ == ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 126))) goto LA33_;
							a = genAddrOf__llCeDV6q0X9bzDY9agj6OpdQ((*n_2)._kind_6.sons->data[((NI) 1)], ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21));
							asgnRef((void**) (&(*field).typ), (*a).typ);
							addField__hrnJBvN8tSy4gj6R5QDcYw(objType, field, (*g).cache);
							T35_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T35_ = newDotExpr__x72gZ9bZdJ0oRpEQKtQFrrg(scratchObj, field);
							T36_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T36_ = newFastAsgnStmt__yLsKlJlR2cWU9b7Mx2ZywyQ(T35_, a);
							add__P8dDSotTW25BkfbyspojGg(result, T36_);
							fieldA = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19), tmpName, (*objType).owner, (*n_2).info, (*(*g).config).options);
							asgnRef((void**) (&(*fieldA).typ), getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg(g, (*n_2).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 31)));
							addField__hrnJBvN8tSy4gj6R5QDcYw(objType, fieldA, (*g).cache);
							T37_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T37_ = newDotExpr__x72gZ9bZdJ0oRpEQKtQFrrg(scratchObj, fieldA);
							T38_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T38_ = newFastAsgnStmt__yLsKlJlR2cWU9b7Mx2ZywyQ(T37_, (*n_2)._kind_6.sons->data[((NI) 2)]);
							add__P8dDSotTW25BkfbyspojGg(result, T38_);
							T39_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T39_ = newDotExpr__x72gZ9bZdJ0oRpEQKtQFrrg(scratchObj, fieldB);
							T40_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T40_ = newFastAsgnStmt__yLsKlJlR2cWU9b7Mx2ZywyQ(T39_, (*n_2)._kind_6.sons->data[((NI) 3)]);
							add__P8dDSotTW25BkfbyspojGg(result, T40_);
							T41_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T41_ = indirectAccess__fh4Yh9bIIARGtqRFUnv8SDA(castExpr, fieldA, (*n_2).info);
							threadLocal_1 = addLocalVar__V3n0eo3maUY9aznyMJYO7VQ(g, varSection, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), owner, (*fieldA).typ, T41_, NIM_TRUE);
							asgnRef((void**) (&(*slice)._kind_6.sons->data[((NI) 2)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(threadLocal_1));
						}
						goto LA30_;
						LA33_: ;
						{
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_2;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T43_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T44_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T45_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T46_;
							tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T47_;
							a_2 = genAddrOf__llCeDV6q0X9bzDY9agj6OpdQ(n_2, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21));
							asgnRef((void**) (&(*field).typ), (*a_2).typ);
							addField__hrnJBvN8tSy4gj6R5QDcYw(objType, field, (*g).cache);
							T43_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T43_ = newDotExpr__x72gZ9bZdJ0oRpEQKtQFrrg(scratchObj, field);
							T44_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T44_ = newFastAsgnStmt__yLsKlJlR2cWU9b7Mx2ZywyQ(T43_, a_2);
							add__P8dDSotTW25BkfbyspojGg(result, T44_);
							T45_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T45_ = newDotExpr__x72gZ9bZdJ0oRpEQKtQFrrg(scratchObj, fieldB);
							T46_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T46_ = genHigh__MV2CjVA8K8K4UngVlqWOhQ_2(g, n_2);
							T47_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
							T47_ = newFastAsgnStmt__yLsKlJlR2cWU9b7Mx2ZywyQ(T45_, T46_);
							add__P8dDSotTW25BkfbyspojGg(result, T47_);
							asgnRef((void**) (&(*slice)._kind_6.sons->data[((NI) 2)]), newIntLit__TuFlkTIoJNHT6fCcycYtSw(g, (*n_2).info, IL64(0)));
						}
						LA30_: ;
						T48_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T48_ = indirectAccess__fh4Yh9bIIARGtqRFUnv8SDA(castExpr, field, (*n_2).info);
						asgnRef((void**) (&(*slice)._kind_6.sons->data[((NI) 1)]), genDeref__jR9bSEA7HO9bL5cUIVgwq7pw(T48_, ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65)));
						T49_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T49_ = indirectAccess__fh4Yh9bIIARGtqRFUnv8SDA(castExpr, fieldB, (*n_2).info);
						threadLocal_2 = addLocalVar__V3n0eo3maUY9aznyMJYO7VQ(g, varSection, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), owner, (*fieldB).typ, T49_, NIM_TRUE);
						asgnRef((void**) (&(*slice)._kind_6.sons->data[((NI) 3)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(threadLocal_2));
						add__P8dDSotTW25BkfbyspojGg(call, slice);
					}
					goto LA25_;
					LA27_: ;
					{
						NIM_BOOL T51_;
						NI64 size;
						NIM_BOOL T52_;
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T55_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a_3;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T58_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T59_;
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* threadLocal_3;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T60_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T61_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T62_;
						T51_ = (NIM_BOOL)0;
						size = computeSize__vCG1GF2Iu043oALVyuJfOw_3((*g).config, argType);
						T52_ = (NIM_BOOL)0;
						T52_ = (size < IL64(0));
						if (T52_) goto LA53_;
						T52_ = (IL64(16) < size);
						LA53_: ;
						T51_ = T52_;
						if (!(T51_)) goto LA54_;
						T55_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
						T55_ = getRoot__QppXrRxPfamDSGF2rYPMlw(n_2);
						T51_ = !((T55_ == ((tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*) NIM_NIL)));
						LA54_: ;
						if (!T51_) goto LA56_;
						a_3 = genAddrOf__llCeDV6q0X9bzDY9agj6OpdQ(n_2, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21));
						asgnRef((void**) (&(*field).typ), (*a_3).typ);
						addField__hrnJBvN8tSy4gj6R5QDcYw(objType, field, (*g).cache);
						T58_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T58_ = newDotExpr__x72gZ9bZdJ0oRpEQKtQFrrg(scratchObj, field);
						T59_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T59_ = newFastAsgnStmt__yLsKlJlR2cWU9b7Mx2ZywyQ(T58_, a_3);
						add__P8dDSotTW25BkfbyspojGg(result, T59_);
						T60_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T60_ = indirectAccess__fh4Yh9bIIARGtqRFUnv8SDA(castExpr, field, (*n_2).info);
						threadLocal_3 = addLocalVar__V3n0eo3maUY9aznyMJYO7VQ(g, varSection, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), owner, (*field).typ, T60_, NIM_TRUE);
						T61_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T61_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(threadLocal_3);
						T62_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T62_ = genDeref__jR9bSEA7HO9bL5cUIVgwq7pw(T61_, ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65));
						add__P8dDSotTW25BkfbyspojGg(call, T62_);
					}
					goto LA25_;
					LA56_: ;
					{
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T64_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T65_;
						tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* threadLocal_4;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T66_;
						tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T67_;
						asgnRef((void**) (&(*field).typ), argType);
						addField__hrnJBvN8tSy4gj6R5QDcYw(objType, field, (*g).cache);
						T64_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T64_ = newDotExpr__x72gZ9bZdJ0oRpEQKtQFrrg(scratchObj, field);
						T65_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T65_ = newFastAsgnStmt__yLsKlJlR2cWU9b7Mx2ZywyQ(T64_, n_2);
						add__P8dDSotTW25BkfbyspojGg(result, T65_);
						T66_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T66_ = indirectAccess__fh4Yh9bIIARGtqRFUnv8SDA(castExpr, field, (*n_2).info);
						threadLocal_4 = addLocalVar__V3n0eo3maUY9aznyMJYO7VQ(g, varSection, varInit, owner, (*field).typ, T66_, NIM_TRUE);
						T67_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
						T67_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(threadLocal_4);
						add__P8dDSotTW25BkfbyspojGg(call, T67_);
					}
					LA25_: ;
				} LA4: ;
				i_2 += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, callProc__7hKLeSMJvLb9cxdy5sc2cbg)(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* a) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*a).info);
	add__P8dDSotTW25BkfbyspojGg(result, a);
	asgnRef((void**) (&(*result).typ), (*(*a).typ).sons->data[((NI) 0)]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TFlowVarKind__lRz5UxeDppZADNanmNd5Yw, flowVarKind__KlDLjCOjghC9c9a79chxEXrnA)(tyObject_ConfigRefcolonObjectType___LaK09ayL9alwKUad7rts0rTw* c, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t) {
	tyEnum_TFlowVarKind__lRz5UxeDppZADNanmNd5Yw result;
	result = (tyEnum_TFlowVarKind__lRz5UxeDppZADNanmNd5Yw)0;
	{
		if (!((48 &((NU16)1<<((NU)((*c).selectedGC)&15U)))!=0)) goto LA3_;
		result = ((tyEnum_TFlowVarKind__lRz5UxeDppZADNanmNd5Yw) 2);
	}
	goto LA1_;
	LA3_: ;
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* T6_;
		T6_ = (tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*)0;
		T6_ = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg(t, IL64(36134350135273744));
		if (!((289406976 &((NU64)1<<((NU)((*T6_).kind)&63U)))!=0)) goto LA7_;
		result = ((tyEnum_TFlowVarKind__lRz5UxeDppZADNanmNd5Yw) 1);
	}
	goto LA1_;
	LA7_: ;
	{
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = containsGarbageCollectedRef__IVXYI9cxSeivThgKCncHRnA_3(t);
		if (!T10_) goto LA11_;
		result = ((tyEnum_TFlowVarKind__lRz5UxeDppZADNanmNd5Yw) 0);
	}
	goto LA1_;
	LA11_: ;
	{
		result = ((tyEnum_TFlowVarKind__lRz5UxeDppZADNanmNd5Yw) 2);
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, createWrapperProc__0GDSFHu1rWYoG5bDx2g4NQ)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* f, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* threadParam, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* argsParam, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varSection, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varInit, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* barrier, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fv, tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw spawnKind, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* result) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* body;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* threadLocalBarrier;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* threadLocalProm;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T28_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T29_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* params;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T74_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T75_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T76_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* t;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T77_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T78_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T79_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* emptyNode;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T80_;
	body = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*f).info);
	threadLocalBarrier = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varSection2;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T5_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T6_;
		if (!!((barrier == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA3_;
		varSection2 = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99), (*barrier).info);
		threadLocalBarrier = addLocalVar__V3n0eo3maUY9aznyMJYO7VQ(g, varSection2, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), result, (*barrier).typ, barrier, NIM_FALSE);
		add__P8dDSotTW25BkfbyspojGg(body, varSection2);
		T5_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T5_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(threadLocalBarrier);
		T6_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T6_ = callCodegenProc__6cD4vACMYqPEkcqC9cypTrw(g, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_33), (*threadLocalBarrier).info, T5_, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		add__P8dDSotTW25BkfbyspojGg(body, T6_);
	}
	LA3_: ;
	threadLocalProm = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
	{
		if (!(spawnKind == ((tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw) 2))) goto LA9_;
		threadLocalProm = addLocalVar__V3n0eo3maUY9aznyMJYO7VQ(g, varSection, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), result, (*fv).typ, fv, NIM_FALSE);
	}
	goto LA7_;
	LA9_: ;
	{
		if (!!((fv == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA12_;
		{
			NimStringDesc* argX60gensym16_;
			if (!!(((*(*fv).typ).kind == ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 11)))) goto LA16_;
			argX60gensym16_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_34);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym16_, TM__OiEZ9cmMV1ztTwyI7NGH1RQ_34);
		}
		LA16_: ;
		threadLocalProm = addLocalVar__V3n0eo3maUY9aznyMJYO7VQ(g, varSection, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), result, (*fv).typ, fv, NIM_FALSE);
	}
	goto LA7_;
	LA12_: ;
	LA7_: ;
	add__P8dDSotTW25BkfbyspojGg(body, varSection);
	add__P8dDSotTW25BkfbyspojGg(body, varInit);
	{
		NIM_BOOL T20_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T24_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T25_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T26_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T27_;
		T20_ = (NIM_BOOL)0;
		T20_ = !((fv == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)));
		if (!(T20_)) goto LA21_;
		T20_ = !((spawnKind == ((tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw) 2)));
		LA21_: ;
		if (!T20_) goto LA22_;
		T24_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T24_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(threadLocalProm);
		T25_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T25_ = indirectAccess__p9aRoyveyldMagH4qkQksIA(T24_, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_35), (*fv).info, (*g).cache);
		T26_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T26_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(threadParam);
		T27_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T27_ = newAsgnStmt__yLsKlJlR2cWU9b7Mx2ZywyQ_2(T25_, T26_);
		add__P8dDSotTW25BkfbyspojGg(body, T27_);
	}
	LA22_: ;
	T28_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T28_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(threadParam);
	T29_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T29_ = callCodegenProc__6cD4vACMYqPEkcqC9cypTrw(g, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_36), (*threadParam).info, T28_, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
	add__P8dDSotTW25BkfbyspojGg(body, T29_);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T34_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T35_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T36_;
		if (!(spawnKind == ((tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw) 2))) goto LA32_;
		T34_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T34_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(threadLocalProm);
		T35_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T35_ = genDeref__jR9bSEA7HO9bL5cUIVgwq7pw(T34_, ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 65));
		T36_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T36_ = newAsgnStmt__yLsKlJlR2cWU9b7Mx2ZywyQ_2(T35_, call);
		add__P8dDSotTW25BkfbyspojGg(body, T36_);
	}
	goto LA30_;
	LA32_: ;
	{
		tyEnum_TFlowVarKind__lRz5UxeDppZADNanmNd5Yw fk;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T46_;
		NimStringDesc* T47_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T53_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T54_;
		if (!!((fv == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA38_;
		fk = flowVarKind__KlDLjCOjghC9c9a79chxEXrnA((*g).config, (*(*fv).typ).sons->data[((NI) 1)]);
		{
			NimStringDesc* T44_;
			NimStringDesc* T45_;
			if (!(fk == ((tyEnum_TFlowVarKind__lRz5UxeDppZADNanmNd5Yw) 0))) goto LA42_;
			T44_ = (NimStringDesc*)0;
			T45_ = (NimStringDesc*)0;
			T45_ = typeToString__QlvraUan7WbHowhAbvDvdA((*(*fv).typ).sons->data[((NI) 1)], ((tyEnum_TPreferedDesc__tnd4qt9c4xddV8oKV5zyusw) 0));
			T44_ = rawNewString((T45_ ? T45_->Sup.len : 0) + 33);
appendString(T44_, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_37));
appendString(T44_, T45_);
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*f).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T44_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__OiEZ9cmMV1ztTwyI7NGH1RQ_38, NIM_FALSE);
		}
		LA42_: ;
		T46_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T46_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(threadLocalProm);
		T47_ = (NimStringDesc*)0;
		{
			if (!(fk == ((tyEnum_TFlowVarKind__lRz5UxeDppZADNanmNd5Yw) 1))) goto LA50_;
			T47_ = copyString(((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_39));
		}
		goto LA48_;
		LA50_: ;
		{
			T47_ = copyString(((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_40));
		}
		LA48_: ;
		T53_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T53_ = indirectAccess__p9aRoyveyldMagH4qkQksIA(T46_, T47_, (*fv).info, (*g).cache);
		T54_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T54_ = newAsgnStmt__yLsKlJlR2cWU9b7Mx2ZywyQ_2(T53_, call);
		add__P8dDSotTW25BkfbyspojGg(body, T54_);
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* incRefCall;
			tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T59_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T60_;
			if (!(fk == ((tyEnum_TFlowVarKind__lRz5UxeDppZADNanmNd5Yw) 1))) goto LA57_;
			incRefCall = newNodeI__UY1ElYk2XqXDzuz9cGLG1Kw(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*fv).info, ((NI) 2));
			T59_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
			T59_ = getSysMagic__F0sH3uZM4wsRv4Pi1Pzwlg(g, (*fv).info, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_41), ((tyEnum_TMagic__shZhZOdbVC5nnFvcXQAImg) 44));
			asgnRef((void**) (&(*incRefCall)._kind_6.sons->data[((NI) 0)]), newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(T59_));
			T60_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T60_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(threadLocalProm);
			asgnRef((void**) (&(*incRefCall)._kind_6.sons->data[((NI) 1)]), indirectAccess__p9aRoyveyldMagH4qkQksIA(T60_, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_39), (*fv).info, (*g).cache));
			add__P8dDSotTW25BkfbyspojGg(body, incRefCall);
		}
		LA57_: ;
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T65_;
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T66_;
			if (!(barrier == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA63_;
			T65_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T65_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(threadLocalProm);
			T66_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T66_ = callCodegenProc__6cD4vACMYqPEkcqC9cypTrw(g, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_42), (*threadLocalProm).info, T65_, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			add__P8dDSotTW25BkfbyspojGg(body, T66_);
		}
		LA63_: ;
	}
	goto LA30_;
	LA38_: ;
	{
		add__P8dDSotTW25BkfbyspojGg(body, call);
	}
	LA30_: ;
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T72_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T73_;
		if (!!((barrier == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA70_;
		T72_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T72_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(threadLocalBarrier);
		T73_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T73_ = callCodegenProc__6cD4vACMYqPEkcqC9cypTrw(g, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_43), (*threadLocalBarrier).info, T72_, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
		add__P8dDSotTW25BkfbyspojGg(body, T73_);
	}
	LA70_: ;
	params = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 76), (*f).info);
	T74_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T74_ = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*f).info);
	add__P8dDSotTW25BkfbyspojGg(params, T74_);
	T75_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T75_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(threadParam);
	add__P8dDSotTW25BkfbyspojGg(params, T75_);
	T76_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T76_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(argsParam);
	add__P8dDSotTW25BkfbyspojGg(params, T76_);
	t = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 25), (*threadParam).owner);
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(t, ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL), NIM_TRUE);
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(t, (*threadParam).typ, NIM_TRUE);
	rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(t, (*argsParam).typ, NIM_TRUE);
	asgnRef((void**) (&(*t).n), newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 76), (*f).info));
	T77_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T77_ = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 152), (*f).info);
	add__P8dDSotTW25BkfbyspojGg((*t).n, T77_);
	T78_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T78_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(threadParam);
	add__P8dDSotTW25BkfbyspojGg((*t).n, T78_);
	T79_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T79_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(argsParam);
	add__P8dDSotTW25BkfbyspojGg((*t).n, T79_);
	emptyNode = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 1), (*f).info);
	T80_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T80_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(result);
	asgnRef((void**) (&(*result).ast), newProcNode__g5PEkYP0A0RT03uHbJ6wKQ(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 79), (*f).info, body, params, T80_, emptyNode, emptyNode, emptyNode, emptyNode));
	asgnRef((void**) (&(*result).typ), t);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*, wrapProcForSpawn__9cWXyScktPXvQmRC9aBs0ADw)(tyObject_ModuleGraphcolonObjectType___RZI3hCs0FTPYx8StfC81qQ* g, tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* owner, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* spawnExpr, tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* retType, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* barrier, tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* dest) {
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* result;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* n;
	NI T1_;
	tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw spawnKind;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fn;
	NimStringDesc* name;
	NimStringDesc* T31_;
	NimStringDesc* T32_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* wrapperProc;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T38_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* threadParam;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T39_;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* argsParam;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T40_;
	tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* objType;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* castExpr;
	tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* scratchObj;
	tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T42_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* call;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varSection;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varInit;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* barrierAsExpr;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fvField;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* fvAsExpr;
	NimStringDesc* T103_;
	NI T104_;
	NimStringDesc* T105_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T106_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T107_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T108_;
	tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T109_;
{	result = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T1_ = (NI)0;
	T1_ = len__P89cqdlERShb9alU3iC0yj8wast(spawnExpr);
	n = (*spawnExpr)._kind_6.sons->data[(NI)(T1_ - ((NI) 2))];
	spawnKind = spawnResult__115WOpmSjJFT089amuDIXdA(retType, !((barrier == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))));
	switch (spawnKind) {
	case ((tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw) 0):
	{
		{
			NimStringDesc* argX60gensym61_;
			if (!!((dest == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA5_;
			argX60gensym61_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_5);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym61_, TM__OiEZ9cmMV1ztTwyI7NGH1RQ_5);
		}
		LA5_: ;
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
	}
	break;
	case ((tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw) 1):
	{
		{
			NimStringDesc* argX60gensym63_;
			if (!!((dest == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA10_;
			argX60gensym63_ = toFileLineCol__fTQr4TRmeNwYlKvcPy3kYAmsgs(TM__OiEZ9cmMV1ztTwyI7NGH1RQ_7);
			internalErrorImpl__PTSwZ6HM9bGBf7vF9cnDmwVw((*g).config, unknownLineInfo__Adg58D2FIbt5TWh9aavBqbg, argX60gensym63_, TM__OiEZ9cmMV1ztTwyI7NGH1RQ_7);
		}
		LA10_: ;
		result = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 126), (*n).info, retType);
	}
	break;
	case ((tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw) 2):
	{
		{
			if (!(dest == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA15_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_8), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__OiEZ9cmMV1ztTwyI7NGH1RQ_9, NIM_FALSE);
		}
		LA15_: ;
		result = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
	}
	break;
	}
	{
		NimStringDesc* T21_;
		NimStringDesc* T22_;
		if (!!(((*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 29) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 30) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 31) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 26) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 28) || (*n).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 32)))) goto LA19_;
		T21_ = (NimStringDesc*)0;
		T22_ = (NimStringDesc*)0;
		T22_ = dollar___qX5C9b0n9bOP7jk69amC8dA7A(n);
		T21_ = rawNewString((T22_ ? T22_->Sup.len : 0) + 37);
appendString(T21_, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_10));
appendString(T21_, T22_);
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), T21_, ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__OiEZ9cmMV1ztTwyI7NGH1RQ_11, NIM_FALSE);
		goto BeforeRet_;
	}
	LA19_: ;
	{
		if (!(((*(*g).config).globalOptions &((NU64)1<<((NU)(((tyEnum_TGlobalOption__RAfAEZqjnKMDumgyKKc1qw) 24))&63U)))!=0)) goto LA25_;
		{
			if (!((130 & (*(*(*n)._kind_6.sons->data[((NI) 0)]).typ).flags) == 0)) goto LA29_;
			liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_12), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__OiEZ9cmMV1ztTwyI7NGH1RQ_13, NIM_FALSE);
		}
		LA29_: ;
	}
	LA25_: ;
	fn = (*n)._kind_6.sons->data[((NI) 0)];
	T31_ = (NimStringDesc*)0;
	T32_ = (NimStringDesc*)0;
	{
		if (!((*fn).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3))) goto LA35_;
		T32_ = copyString((*(*(*fn)._kind_4.sym).name).s);
	}
	goto LA33_;
	LA35_: ;
	{
		T32_ = copyString(((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_14));
	}
	LA33_: ;
	T31_ = rawNewString((T32_ ? T32_->Sup.len : 0) + 7);
appendString(T31_, T32_);
appendString(T31_, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_15));
	name = T31_;
	T38_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T38_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*g).cache, name);
	wrapperProc = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 12), T38_, owner, (*fn).info, (*(*g).config).options);
	T39_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T39_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*g).cache, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_16));
	threadParam = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3), T39_, wrapperProc, (*n).info, (*(*g).config).options);
	T40_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T40_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*g).cache, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_17));
	argsParam = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 3), T40_, wrapperProc, (*n).info, (*(*g).config).options);
	(*wrapperProc).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 41)) & 63);
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* ptrType;
		ptrType = getSysType__VcTNc9cK1Ftuh0MFwOC9c0Tg(g, (*n).info, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 26));
		asgnRef((void**) (&(*threadParam).typ), ptrType);
		asgnRef((void**) (&(*argsParam).typ), ptrType);
		(*argsParam).position = ((NI) 1);
	}
	objType = createObj__vpIcmDdKH7ed0dcs37b1GQ(g, owner, (*n).info, NIM_TRUE);
	(*objType).flags |= ((NU64)1)<<((((tyEnum_TTypeFlag__x2m5g1NpbmDig4wLT3Ylhw) 2)) & 63);
	castExpr = createCastExpr__0ABsbrKg8HOlgwf7OVsO6A(argsParam, objType);
	T42_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
	T42_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*g).cache, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_18));
	scratchObj = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 8), T42_, owner, (*n).info, (*(*g).config).options);
	{
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* varSectionB;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T44_;
		asgnRef((void**) (&(*scratchObj).typ), objType);
		(*scratchObj).flags |= ((NU64)1)<<((((tyEnum_TSymFlag__K9ay6LWMat9bUiT9bIbMxpDHw) 2)) & 63);
		varSectionB = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99), (*n).info);
		T44_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T44_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(scratchObj);
		addVar__qOCBdprWtK4hxer73SEdQA(varSectionB, T44_);
		add__P8dDSotTW25BkfbyspojGg(result, varSectionB);
	}
	call = newNodeIT__2kgyckjaq2XB9bxBo5ZeIbg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 27), (*n).info, (*n).typ);
	{
		NIM_BOOL T47_;
		NIM_BOOL T49_;
		T47_ = (NIM_BOOL)0;
		T47_ = ((*fn).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 155));
		if (T47_) goto LA48_;
		T49_ = (NIM_BOOL)0;
		T49_ = !(((*fn).typ == ((tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ*) NIM_NIL)));
		if (!(T49_)) goto LA50_;
		T49_ = ((*(*fn).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9));
		LA50_: ;
		T47_ = T49_;
		LA48_: ;
		if (!T47_) goto LA51_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_19), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__OiEZ9cmMV1ztTwyI7NGH1RQ_20, NIM_FALSE);
	}
	LA51_: ;
	{
		NIM_BOOL T55_;
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* argType;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T59_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T60_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T61_;
		T55_ = (NIM_BOOL)0;
		T55_ = ((*fn).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T55_)) goto LA56_;
		T55_ = ((487424 &((NU32)1<<((NU)((*(*fn)._kind_4.sym).kind)&31U)))!=0);
		LA56_: ;
		if (!!(T55_)) goto LA57_;
		argType = skipTypes__zsqmUNR5OZrTUna0Y9bdu9bg((*(*n)._kind_6.sons->data[((NI) 0)]).typ, IL64(36134350135273744));
		T59_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T59_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*g).cache, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_21));
		field = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19), T59_, owner, (*n).info, (*(*g).config).options);
		asgnRef((void**) (&(*field).typ), argType);
		addField__hrnJBvN8tSy4gj6R5QDcYw(objType, field, (*g).cache);
		T60_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T60_ = newDotExpr__x72gZ9bZdJ0oRpEQKtQFrrg(scratchObj, field);
		T61_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T61_ = newFastAsgnStmt__yLsKlJlR2cWU9b7Mx2ZywyQ(T60_, (*n)._kind_6.sons->data[((NI) 0)]);
		add__P8dDSotTW25BkfbyspojGg(result, T61_);
		fn = indirectAccess__fh4Yh9bIIARGtqRFUnv8SDA(castExpr, field, (*n).info);
	}
	goto LA53_;
	LA57_: ;
	{
		NIM_BOOL T63_;
		T63_ = (NIM_BOOL)0;
		T63_ = ((*fn).kind == ((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 3));
		if (!(T63_)) goto LA64_;
		T63_ = ((*(*fn)._kind_4.sym).kind == ((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 15));
		LA64_: ;
		if (!T63_) goto LA65_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_22), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__OiEZ9cmMV1ztTwyI7NGH1RQ_23, NIM_FALSE);
	}
	goto LA53_;
	LA65_: ;
	{
		if (!((*(*fn).typ).callConv == ((tyEnum_TCallingConvention__yjAJ8w0h1PBaSwSGJ3P7IA) 9))) goto LA68_;
		liMessage__Q6JNH4uRwLyZrj0dJakHew((*g).config, (*n).info, ((tyEnum_TMsgKind__29cbg2fC1z5iM1PAI28kR5w) 10), ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_19), ((tyEnum_TErrorHandling__q4fXoCN3Xdcm6SS9cUkWkWw) 0), TM__OiEZ9cmMV1ztTwyI7NGH1RQ_24, NIM_FALSE);
	}
	goto LA53_;
	LA68_: ;
	LA53_: ;
	add__P8dDSotTW25BkfbyspojGg(call, fn);
	varSection = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 99), (*n).info);
	varInit = newNodeI__vokyXY9cZDshCSxFKChhG9bg(((tyEnum_TNodeKind__G4E4Gxe7oI2Cm03rkiOzQw) 115), (*n).info);
	{
		if (!(barrier == 0)) goto LA72_;
		setupArgsForConcurrency__uvJ57za4ek56COpyhrRjcw(g, n, objType, wrapperProc, scratchObj, castExpr, call, varSection, varInit, result);
	}
	goto LA70_;
	LA72_: ;
	{
		setupArgsForParallelism__uvJ57za4ek56COpyhrRjcw_2(g, n, objType, wrapperProc, scratchObj, castExpr, call, varSection, varInit, result);
	}
	LA70_: ;
	barrierAsExpr = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	{
		tyObject_TType__v9ae2Dpu13OW2ZJ2U9bNMd9cQ* typ;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* T79_;
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field_2;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T80_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T81_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T82_;
		if (!!((barrier == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL)))) goto LA77_;
		typ = newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21), owner);
		T79_ = (tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w*)0;
		T79_ = getCompilerProc__4qXS5VHrKJ5hq9crvvz8tIA(g, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_29));
		rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg(typ, (*T79_).typ, NIM_TRUE);
		T80_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T80_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*g).cache, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_30));
		field_2 = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19), T80_, owner, (*n).info, (*(*g).config).options);
		asgnRef((void**) (&(*field_2).typ), typ);
		addField__hrnJBvN8tSy4gj6R5QDcYw(objType, field_2, (*g).cache);
		T81_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T81_ = newDotExpr__x72gZ9bZdJ0oRpEQKtQFrrg(scratchObj, field_2);
		T82_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T82_ = newFastAsgnStmt__yLsKlJlR2cWU9b7Mx2ZywyQ(T81_, barrier);
		add__P8dDSotTW25BkfbyspojGg(result, T82_);
		barrierAsExpr = indirectAccess__fh4Yh9bIIARGtqRFUnv8SDA(castExpr, field_2, (*n).info);
	}
	LA77_: ;
	fvField = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	fvAsExpr = ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL);
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field_3;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T87_;
		NI T88_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T89_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T90_;
		if (!(spawnKind == ((tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw) 1))) goto LA85_;
		T87_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T87_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*g).cache, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_31));
		field_3 = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19), T87_, owner, (*n).info, (*(*g).config).options);
		asgnRef((void**) (&(*field_3).typ), retType);
		addField__hrnJBvN8tSy4gj6R5QDcYw(objType, field_3, (*g).cache);
		fvField = newDotExpr__x72gZ9bZdJ0oRpEQKtQFrrg(scratchObj, field_3);
		fvAsExpr = indirectAccess__fh4Yh9bIIARGtqRFUnv8SDA(castExpr, field_3, (*n).info);
		T88_ = (NI)0;
		T88_ = len__P89cqdlERShb9alU3iC0yj8wast(spawnExpr);
		T89_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T89_ = callProc__7hKLeSMJvLb9cxdy5sc2cbg((*spawnExpr)._kind_6.sons->data[(NI)(T88_ - ((NI) 1))]);
		T90_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T90_ = newFastAsgnStmt__yLsKlJlR2cWU9b7Mx2ZywyQ(fvField, T89_);
		add__P8dDSotTW25BkfbyspojGg(result, T90_);
		{
			tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T95_;
			if (!(barrier == ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL))) goto LA93_;
			T95_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
			T95_ = callCodegenProc__6cD4vACMYqPEkcqC9cypTrw(g, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_32), (*fvField).info, fvField, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL));
			add__P8dDSotTW25BkfbyspojGg(result, T95_);
		}
		LA93_: ;
	}
	goto LA83_;
	LA85_: ;
	{
		tyObject_TSym__JpsEh5i1AcKChGYbg7aV4w* field_4;
		tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA* T99_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T100_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T101_;
		tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw* T102_;
		if (!(spawnKind == ((tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw) 2))) goto LA97_;
		T99_ = (tyObject_TIdent__GufRQq9c0miSybX3zBD4tyA*)0;
		T99_ = getIdent__9coBOmdXN09be4rJvXK6fQGQ((*g).cache, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_31));
		field_4 = newSym__IXbidcxhXTQGZY9abN63Cxg(((tyEnum_TSymKind__cNCW9acsSznmEccl1fgQwkw) 19), T99_, owner, (*n).info, (*(*g).config).options);
		asgnRef((void**) (&(*field_4).typ), newType__SNqpa06pdVCLFFBR28119aQ(((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21), (*objType).owner));
		rawAddSon__LW9aGb2JfjdMXhDZwQYa5xg((*field_4).typ, retType, NIM_TRUE);
		addField__hrnJBvN8tSy4gj6R5QDcYw(objType, field_4, (*g).cache);
		fvAsExpr = indirectAccess__fh4Yh9bIIARGtqRFUnv8SDA(castExpr, field_4, (*n).info);
		T100_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T100_ = newDotExpr__x72gZ9bZdJ0oRpEQKtQFrrg(scratchObj, field_4);
		T101_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T101_ = genAddrOf__llCeDV6q0X9bzDY9agj6OpdQ(dest, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21));
		T102_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
		T102_ = newFastAsgnStmt__yLsKlJlR2cWU9b7Mx2ZywyQ(T100_, T101_);
		add__P8dDSotTW25BkfbyspojGg(result, T102_);
	}
	goto LA83_;
	LA97_: ;
	LA83_: ;
	createTypeBoundOps__HRpOwQj0TjFM8eZsKc7jlw(g, ((tyObject_TContext__C9bB2okDBl3OKGUBiY5k5Ug*) NIM_NIL), objType, (*n).info);
	createWrapperProc__0GDSFHu1rWYoG5bDx2g4NQ(g, fn, threadParam, argsParam, varSection, varInit, call, barrierAsExpr, fvAsExpr, spawnKind, wrapperProc);
	T103_ = (NimStringDesc*)0;
	T104_ = (NI)0;
	T104_ = len__P89cqdlERShb9alU3iC0yj8wast(spawnExpr);
	T105_ = (NimStringDesc*)0;
	T105_ = nimIntToStr(T104_);
	T103_ = rawNewString((T105_ ? T105_->Sup.len : 0) + 8);
appendString(T103_, ((NimStringDesc*) &TM__OiEZ9cmMV1ztTwyI7NGH1RQ_44));
appendString(T103_, T105_);
	T106_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T106_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(wrapperProc);
	T107_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T107_ = newSymNode__I2DV2TmmOysY1ZEGW19b9bRg(scratchObj);
	T108_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T108_ = genAddrOf__llCeDV6q0X9bzDY9agj6OpdQ(T107_, ((tyEnum_TTypeKind__9a3YiReNVD0IJHWFKgXRe9ag) 21));
	T109_ = (tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*)0;
	T109_ = callCodegenProc__6cD4vACMYqPEkcqC9cypTrw(g, T103_, (*wrapperProc).info, T106_, T108_, ((tyObject_TNode__bROa11lyF5vxEN9aYNbHmhw*) NIM_NIL), spawnExpr);
	add__P8dDSotTW25BkfbyspojGg(result, T109_);
	{
		if (!(spawnKind == ((tyEnum_TSpawnResult__YOcUu9brt5AKRflRWdxATPw) 1))) goto LA112_;
		add__P8dDSotTW25BkfbyspojGg(result, fvField);
	}
	LA112_: ;
	}BeforeRet_: ;
	return result;
}
